@font-face {
  font-family: 'Icinga-Icons';
  src:  url('@{iplWebAssets}/font/Icinga-Icons.eot');
  src:  url('@{iplWebAssets}/font/Icinga-Icons.eot') format('embedded-opentype'),
  url('@{iplWebAssets}/font/Icinga-Icons.ttf') format('truetype'),
  url('@{iplWebAssets}/font/Icinga-Icons.woff') format('woff'),
  url('@{iplWebAssets}/font/Icinga-Icons.svg') format('svg');
  font-weight: normal;
  font-style: normal;
  font-display: block;
}

[class^="iicon-"]:before, [class*=" iicon-"]:before {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'Icinga-Icons';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1em;

  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.iicon-minimal:before {
  content: "\e900";
}
.iicon-detailed:before {
  content: "\e901";
}
.iicon-default:before {
  content: "\e902";
}
